# annsel

```{include} ./badges.md

```

::::{grid} 1 2 2 3
:gutter: 1 1 1 2

:::{grid-item-card} {octicon}`book;1.5em;sd-mr-1` All of `annsel`
:link: ./notebooks/all_of_annsel
:link-type: doc
Learn how to use `annsel`.

+++
**View »**
:::

:::{grid-item-card} {octicon}`file-code;1.5em;sd-mr-1` API Documentation
:link: api/index
:link-type: doc

Read the API documentation.

+++
**View »**
:::

::::

---

## Getting started

Please refer to the [documentation](https://annsel.readthedocs.io),
in particular, the [API documentation](https://annsel.readthedocs.io/en/latest/api.html).

## Installation

You need to have Python 3.10 or newer installed on your system. If you don't have
Python installed, we recommend installing [uv](https://github.com/astral-sh/uv).
There are several alternative options to install `annsel`:

1. Install the most recent release:

    :::::{tabs}
    ::::{group-tab} uv
    If you are using `uv`

    ```zsh
    uv add annsel
    ```

    ::::

    ::::{group-tab} Pip
    If you are using `pip`:

    ```zsh
    pip install annsel
    ```

    ::::
    :::::

2. Install the latest development version:

    :::::{tabs}
    ::::{group-tab} uv
    If you are using `uv`

    ```zsh
    uv add git+https://github.com/srivarra/annsel
    ```

    ::::

    ::::{group-tab} Pip
    If you are using `pip`:

    ```zsh
    pip install git+https://github.com/srivarra/annsel.git@main
    ```

    ::::
    :::::

## Release notes

See the [changelog](https://annsel.readthedocs.io/latest/changelog.html).

## Contact

For questions and help requests, you can reach out in the [scverse discourse](https://discourse.scverse.org/) or the [discussions](https://github.com/srivarra/annsel/discussions) tab.
If you found a bug, please use the [issue tracker](https://github.com/srivarra/annsel/issues).

## Other

If you are interested in how `annsel` works, feel free to take a look at the [developer log (offsite)](https://www.srivarra.dev/posts/annsel/devlog-01/).

## Citation

> Varra, S. R. annsel [Computer software]. https://github.com/srivarra/annsel
